==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/my/activity-stream-strings.js <==
// Note - this is a generated my file.
window.gActivityStreamStrings = {
  "newtab_page_title": "တပ်ဗ်အသစ်ဖွင့်",
  "header_top_sites": "အများဆုံးသုံးဆိုက်များ",
  "header_highlights": "ဦးစားပေးအကြောင်းအရာများ",
  "header_recommended_by": "{provider} က အကြံပြုထားသည်",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "သွားလည်ခဲ့သော",
  "type_label_bookmarked": "စာအမှတ်မှတ်ထားသော",
  "type_label_recommended": "လူကြိုက်များနေသော",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "စာအမှတ်",
  "menu_action_remove_bookmark": "စာအမှတ်အားဖယ်ပါ",
  "menu_action_open_new_window": "အခြားဝင်းဒိုးတစ်ခုမှဖွင့်ပါ",
  "menu_action_open_private_window": "အခြားတစ်ကိုယ်ရေသုံးဝင်းဒိုးတစ်ခုဖွင့်ပါ",
  "menu_action_dismiss": "ပိတ်လိုက်ပါ",
  "menu_action_delete": "မှတ်တမ်းမှ ဖျက်ပါ",
  "menu_action_pin": "တွယ်ရန်",
  "menu_action_unpin": "တွယ်ဖြုတ်ရန်",
  "confirm_history_delete_p1": "ယခုစာမျက်နှာနှင့် ဆိုင်သော အရာအားလုံးကို မှတ်တမ်းမှ ဖယ်ရှားလိုပါသလား။",
  "confirm_history_delete_notice_p2": "ယခုလုပ်ဆောင်မှုသည် နောက်ပြန်ဆုတ်၍မရသော လုပ်ဆောင်မှု ဖြစ်သည်။",
  "menu_action_save_to_pocket": "Pocket သို့ သိမ်းရန်",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "ရှာ",
  "search_header": "{search_engine_name} ရှာဖွေမှု",
  "search_web_placeholder": "ဝတ်ဘ်ပေါ်တွင် ရှာဖွေခြင်း",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "သင့်တပ်ဗ်အသစ်စာမျက်နှာအား ပြင်ဆင်မည်",
  "settings_pane_topsites_header": "ထိပ်တန်းဝတ်ဘ်ဆိုက်များ",
  "settings_pane_highlights_header": "ဦးစားပေးအကြောင်းအရာများ",
  "settings_pane_highlights_options_bookmarks": "စာမှတ်များ",
  "settings_pane_snippets_header": "မှတ်စုတိုများ",
  "edit_topsites_button_text": "ပြင်ဆင်မည်",
  "edit_topsites_edit_button": "ဆိုက်အားပြင်မည်",
  "topsites_form_add_header": "ထိပ်တန်းဆိုက် အသစ်",
  "topsites_form_edit_header": "ထိပ်တန်းဆိုက်ကို တည်းဖြတ်ရန်",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "ခေါင်းစဉ် ရေးပါ",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "URL ကို ရိုက်ပါ သို့မဟုတ် ပွားထည့်ပါ",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "ထည့်ရန်",
  "topsites_form_save_button": "သိမ်းရန်",
  "topsites_form_cancel_button": "မလုပ်တော့ပါ",
  "topsites_form_url_validation": "URL အမှန် လိုအပ်သည်",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "လူကြိုက်များခေါင်းစဉ်များ",
  "pocket_read_even_more": "နောက်ထပ်သတင်းများ ကြည့်ရန်",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "အခြားဘရောင်ဇာမှ စာမှတ်များ၊ မှတ်တမ်းများ၊ စကားဝှက်များနှင့်အတူ Firefox တွင် စမ်းသုံးကြည့်ပါ။",
  "manual_migration_cancel_button": "မလိုတော့ပါ၊ ကျေးဇူးတင်ပါသည်။",
  "manual_migration_import_button": "ထည့်သွင်းရန်",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "ရယူနေသှ်…",
  "header_stories": "အကြည့်အများဆုံးသတင်းများ",
  "header_visit_again": "ထပ်မံလည်ပတ်ရန်",
  "header_bookmarks": "လတ်တလော စာမှတ်များ",
  "header_bookmarks_placeholder": "မည်သည့်စာမှတ်မျှ မရှိသေးပါ။",
  "header_stories_from": "မှ",
  "type_label_synced": "အခြားပစ္စည်းတစ်ခုမှရယူထားသှ်",
  "type_label_open": "ဖွင့်ပါ",
  "type_label_topic": "အကြောင်းအရာ",
  "type_label_now": "ယခု",
  "menu_action_copy_address": "လိပ်စာအားကူးယူပါ",
  "menu_action_email_link": "လင်ခ့်အားအီးမေလ်းဖြင့်ပို့ပါ…",
  "search_for_something_with": "{search_term} အားရှာပါ -",
  "search_settings": "ရှာဖွေမှုအပြင်အဆင်အားပြောင်းလဲပါ",
  "section_info_option": "အချက်အလက်",
  "section_info_send_feedback": "အကြံပေးချက် ပေးပို့ရန်",
  "section_info_privacy_notice": "ကိုယ်ရေးကာကွယ်မှု သတိပေးချက်",
  "welcome_title": "တပ်ဗ်အသစ်တစ်ခုမှကြိုဆိုပါတယ်",
  "welcome_body": "ယခုနေရာအား Firefox မှ အသင့်လျော်ဆုံး သင်သွားလည်ခဲ့ဖူးသော စာအမှတ်များ၊ ဆောင်းပါးများ၊ ရုပ်ရှင်များ နှင့် စာမျက်နှာများအား ပြသဖို့အသုံးပြုမည်ဖြစ်ပါတယ်။",
  "welcome_label": "သင့် အသားပေးဖော်ပြချက်များကိုသတိထားမည်",
  "time_label_less_than_minute": "<1မီတာ",
  "time_label_minute": "{number}မီတာ",
  "time_label_hour": "{number}အမြင့်",
  "time_label_day": "{number}နေ့",
  "settings_pane_header": "စာတပ်ဗ်အသစ်အပြင်အဆင်များ",
  "settings_pane_body2": "ယခုစာမျက်နှာတွင် ကြည့်လိုသည်များကို ရွေးပါ။",
  "settings_pane_search_header": "ရှာဖွေပါ",
  "settings_pane_search_body": "ဝက်ဘ်ပေါ်တွင် သင့်တပ်ဗ်အသစ်မှရှာဖွေပါ",
  "settings_pane_topsites_body": "သင်အများဆုံးသွားလည်သော ဝတ်ဘ်ဆိုက်များကို ရယူပါ",
  "settings_pane_topsites_options_showmore": "အတန်းနှစ်တန်းနှင့်ပြပါ",
  "settings_pane_bookmarks_header": "လတ်တလော စာမှတ်များ",
  "settings_pane_bookmarks_body": "အသစ်မှတ်သားထားသော စာမှတ်များကို တစ်နေရာတည်းတွင် စုစည်းထားသည်။",
  "settings_pane_visit_again_header": "ထပ်မံလည်ပတ်ရန်",
  "settings_pane_visit_again_body": "မှတ်ထားလိုသော သို့မဟုတ် ပြန်ဖွင့်လိုသော လည်ပတ်မှတ်တမ်းထဲမှ တချို့ကို Firefox က ပြပါမည်။",
  "settings_pane_highlights_options_visited": "လည်ပတ်ထားသော ဆိုက်များ",
  "settings_pane_snippets_body": "Mozilla မှ Firefox အကြောင်း၊ အင်တာနက်ယဉ်ကျေးမှုနှင့် အခါအားလျော်စွာ ဖြစ်ပေါ်လာသော ကျပန်း meme စသည့် နောက်ဆုံးရသတင်းများကို ဖတ်ရှုပါ။",
  "settings_pane_done_button": "ပြီးပြီ",
  "edit_topsites_button_label": "သင့်ထိပ်တန်းဆိုက် အမြင်အားပြင်ဆင်ပါ",
  "edit_topsites_showmore_button": "ထပ်ပြပါ",
  "edit_topsites_showless_button": "ချုံ့ပြရန်",
  "edit_topsites_done_button": "ပြီးပြီ",
  "edit_topsites_pin_button": "ဝတ်ဆိုဒ်အားpinလုပ်ထားမည်",
  "edit_topsites_unpin_button": "ယခုဆိုက်ကို တွယ်ဖြုတ်ရန်",
  "edit_topsites_dismiss_button": "ဆိုက်အားဖျက်လိုက်မည်",
  "edit_topsites_add_button": "ထည့်ရန်"
};

==> firefox-62.0b18.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/my/activity-stream-strings.js <==
// Note - this is a generated my file.
window.gActivityStreamStrings = {
  "newtab_page_title": "တပ်ဗ်အသစ်ဖွင့်",
  "header_top_sites": "အများဆုံးသုံးဆိုက်များ",
  "header_highlights": "ဦးစားပေးအကြောင်းအရာများ",
  "header_recommended_by": "{provider} က အကြံပြုထားသည်",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "သွားလည်ခဲ့သော",
  "type_label_bookmarked": "စာအမှတ်မှတ်ထားသော",
  "type_label_recommended": "လူကြိုက်များနေသော",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "စာအမှတ်",
  "menu_action_remove_bookmark": "စာအမှတ်အားဖယ်ပါ",
  "menu_action_open_new_window": "အခြားဝင်းဒိုးတစ်ခုမှဖွင့်ပါ",
  "menu_action_open_private_window": "အခြားတစ်ကိုယ်ရေသုံးဝင်းဒိုးတစ်ခုဖွင့်ပါ",
  "menu_action_dismiss": "ပိတ်လိုက်ပါ",
  "menu_action_delete": "မှတ်တမ်းမှ ဖျက်ပါ",
  "menu_action_pin": "တွယ်ရန်",
  "menu_action_unpin": "တွယ်ဖြုတ်ရန်",
  "confirm_history_delete_p1": "ယခုစာမျက်နှာနှင့် ဆိုင်သော အရာအားလုံးကို မှတ်တမ်းမှ ဖယ်ရှားလိုပါသလား။",
  "confirm_history_delete_notice_p2": "ယခုလုပ်ဆောင်မှုသည် နောက်ပြန်ဆုတ်၍မရသော လုပ်ဆောင်မှု ဖြစ်သည်။",
  "menu_action_save_to_pocket": "Pocket သို့ သိမ်းရန်",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "ရှာ",
  "search_header": "{search_engine_name} ရှာဖွေမှု",
  "search_web_placeholder": "ဝတ်ဘ်ပေါ်တွင် ရှာဖွေခြင်း",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "သင့်တပ်ဗ်အသစ်စာမျက်နှာအား ပြင်ဆင်မည်",
  "settings_pane_topsites_header": "ထိပ်တန်းဝတ်ဘ်ဆိုက်များ",
  "settings_pane_highlights_header": "ဦးစားပေးအကြောင်းအရာများ",
  "settings_pane_highlights_options_bookmarks": "စာမှတ်များ",
  "settings_pane_snippets_header": "မှတ်စုတိုများ",
  "edit_topsites_button_text": "ပြင်ဆင်မည်",
  "edit_topsites_edit_button": "ဆိုက်အားပြင်မည်",
  "topsites_form_add_header": "ထိပ်တန်းဆိုက် အသစ်",
  "topsites_form_edit_header": "ထိပ်တန်းဆိုက်ကို တည်းဖြတ်ရန်",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "ခေါင်းစဉ် ရေးပါ",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "URL ကို ရိုက်ပါ သို့မဟုတ် ပွားထည့်ပါ",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "ထည့်ရန်",
  "topsites_form_save_button": "သိမ်းရန်",
  "topsites_form_cancel_button": "မလုပ်တော့ပါ",
  "topsites_form_url_validation": "URL အမှန် လိုအပ်သည်",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "လူကြိုက်များခေါင်းစဉ်များ",
  "pocket_read_even_more": "နောက်ထပ်သတင်းများ ကြည့်ရန်",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "အခြားဘရောင်ဇာမှ စာမှတ်များ၊ မှတ်တမ်းများ၊ စကားဝှက်များနှင့်အတူ Firefox တွင် စမ်းသုံးကြည့်ပါ။",
  "manual_migration_cancel_button": "မလိုတော့ပါ၊ ကျေးဇူးတင်ပါသည်။",
  "manual_migration_import_button": "ထည့်သွင်းရန်",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_manage_webext": "Manage Extension",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_add_search_engine": "Add Search Engine",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "firstrun_title": "Take Firefox with You",
  "firstrun_content": "Get your bookmarks, history, passwords and other settings on all your devices.",
  "firstrun_learn_more_link": "Learn more about Firefox Accounts",
  "firstrun_form_header": "Enter your email",
  "firstrun_form_sub_header": "to continue to Firefox Sync",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_invalid_input": "Valid email required",
  "firstrun_extra_legal_links": "By proceeding, you agree to the {terms} and {privacy}.",
  "firstrun_terms_of_service": "Terms of Service",
  "firstrun_privacy_notice": "Privacy Notice",
  "firstrun_continue_to_login": "Continue",
  "firstrun_skip_login": "Skip this step",
  "default_label_loading": "ရယူနေသှ်…",
  "header_stories": "အကြည့်အများဆုံးသတင်းများ",
  "header_visit_again": "ထပ်မံလည်ပတ်ရန်",
  "header_bookmarks": "လတ်တလော စာမှတ်များ",
  "header_bookmarks_placeholder": "မည်သည့်စာမှတ်မျှ မရှိသေးပါ။",
  "header_stories_from": "မှ",
  "type_label_synced": "အခြားပစ္စည်းတစ်ခုမှရယူထားသှ်",
  "type_label_open": "ဖွင့်ပါ",
  "type_label_topic": "အကြောင်းအရာ",
  "type_label_now": "ယခု",
  "menu_action_copy_address": "လိပ်စာအားကူးယူပါ",
  "menu_action_email_link": "လင်ခ့်အားအီးမေလ်းဖြင့်ပို့ပါ…",
  "search_for_something_with": "{search_term} အားရှာပါ -",
  "search_settings": "ရှာဖွေမှုအပြင်အဆင်အားပြောင်းလဲပါ",
  "section_info_option": "အချက်အလက်",
  "section_info_send_feedback": "အကြံပေးချက် ပေးပို့ရန်",
  "section_info_privacy_notice": "ကိုယ်ရေးကာကွယ်မှု သတိပေးချက်",
  "welcome_title": "တပ်ဗ်အသစ်တစ်ခုမှကြိုဆိုပါတယ်",
  "welcome_body": "ယခုနေရာအား Firefox မှ အသင့်လျော်ဆုံး သင်သွားလည်ခဲ့ဖူးသော စာအမှတ်များ၊ ဆောင်းပါးများ၊ ရုပ်ရှင်များ နှင့် စာမျက်နှာများအား ပြသဖို့အသုံးပြုမည်ဖြစ်ပါတယ်။",
  "welcome_label": "သင့် အသားပေးဖော်ပြချက်များကိုသတိထားမည်",
  "time_label_less_than_minute": "<1မီတာ",
  "time_label_minute": "{number}မီတာ",
  "time_label_hour": "{number}အမြင့်",
  "time_label_day": "{number}နေ့",
  "settings_pane_header": "စာတပ်ဗ်အသစ်အပြင်အဆင်များ",
  "settings_pane_body2": "ယခုစာမျက်နှာတွင် ကြည့်လိုသည်များကို ရွေးပါ။",
  "settings_pane_search_header": "ရှာဖွေပါ",
  "settings_pane_search_body": "ဝက်ဘ်ပေါ်တွင် သင့်တပ်ဗ်အသစ်မှရှာဖွေပါ",
  "settings_pane_topsites_body": "သင်အများဆုံးသွားလည်သော ဝတ်ဘ်ဆိုက်များကို ရယူပါ",
  "settings_pane_topsites_options_showmore": "အတန်းနှစ်တန်းနှင့်ပြပါ",
  "settings_pane_bookmarks_header": "လတ်တလော စာမှတ်များ",
  "settings_pane_bookmarks_body": "အသစ်မှတ်သားထားသော စာမှတ်များကို တစ်နေရာတည်းတွင် စုစည်းထားသည်။",
  "settings_pane_visit_again_header": "ထပ်မံလည်ပတ်ရန်",
  "settings_pane_visit_again_body": "မှတ်ထားလိုသော သို့မဟုတ် ပြန်ဖွင့်လိုသော လည်ပတ်မှတ်တမ်းထဲမှ တချို့ကို Firefox က ပြပါမည်။",
  "settings_pane_highlights_options_visited": "လည်ပတ်ထားသော ဆိုက်များ",
  "settings_pane_snippets_body": "Mozilla မှ Firefox အကြောင်း၊ အင်တာနက်ယဉ်ကျေးမှုနှင့် အခါအားလျော်စွာ ဖြစ်ပေါ်လာသော ကျပန်း meme စသည့် နောက်ဆုံးရသတင်းများကို ဖတ်ရှုပါ။",
  "settings_pane_done_button": "ပြီးပြီ",
  "edit_topsites_button_label": "သင့်ထိပ်တန်းဆိုက် အမြင်အားပြင်ဆင်ပါ",
  "edit_topsites_showmore_button": "ထပ်ပြပါ",
  "edit_topsites_showless_button": "ချုံ့ပြရန်",
  "edit_topsites_done_button": "ပြီးပြီ",
  "edit_topsites_pin_button": "ဝတ်ဆိုဒ်အားpinလုပ်ထားမည်",
  "edit_topsites_unpin_button": "ယခုဆိုက်ကို တွယ်ဖြုတ်ရန်",
  "edit_topsites_dismiss_button": "ဆိုက်အားဖျက်လိုက်မည်",
  "edit_topsites_add_button": "ထည့်ရန်"
};
